=====
Grail
=====
Grail is a library which allows test script creation based on steps.

Library usage brings the following benefits to your tests:

- strict separation test logic from test implementation

- you don't need separate test cases as a documentation for your tests, it will be generated from the code

- separate logging is not required, test execution is automatically logged

- test script creation is easy for people with basic programming skills

- step implementation can be done separately

More usage details are available here: http://wgnet.github.io/grail/.